/**
 * Copyright (c) 2012 - 2019 Data In Motion and others.
 * All rights reserved. 
 * 
 * This program and the accompanying materials are made available under the terms of the 
 * Eclipse Public License v1.0 which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     Data In Motion - initial API and implementation
 */
package org.gecko.rsa.discovery.ma;

import java.util.logging.Logger;

import org.gecko.osgi.messaging.MessagingService;
import org.gecko.rsa.discovery.ma.handler.MADiscoveryConfig;
import org.gecko.rsa.discovery.ma.handler.MessageAdapterDiscoverHandler;
import org.osgi.annotation.bundle.Capability;
import org.osgi.framework.BundleContext;
import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.ConfigurationPolicy;
import org.osgi.service.component.annotations.Deactivate;
import org.osgi.service.component.annotations.Reference;

/**
 * Configurable component to create a new discovery for a message adapter
 * @author Mark Hoffmann
 * @since 05.04.2019
 */
@Capability(namespace="osgi.remoteserviceadmin.discovery", version="1.1", attribute="protocols:List<String>=ma")
@Component(immediate=true, configurationPolicy=ConfigurationPolicy.REQUIRE, name="MessageAdapterDiscovery", configurationPid="MessageAdapterDiscovery")
public class MessageAdapterDiscoveryComponent {

	private static final Logger logger = Logger.getLogger(MessageAdapterDiscoveryComponent.class.getName());
	
	@Reference(name="messaging")
	private MessagingService messaging;
	private MessageAdapterDiscoverHandler handler;
	private MADiscoveryConfig config;

	@Activate
	public void activate(BundleContext context, MADiscoveryConfig config) {
		this.config = config;
		handler = new MessageAdapterDiscoverHandler(messaging, context, config);
		handler.start();
		logger.fine(String.format("[%s] Started message adapter discovery", config.name()));
	}
	
	@Deactivate
	public void deactivate() {
		handler.stop();
		logger.fine(String.format("[%s] Stopped message adapter discovery", config.name()));
	}
	
}
